==> gottet-1.0.5-src.tar.bz2: gottet-1.0.5/translations/gottet_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="89"/>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="89"/>
        <source>End the current game?</source>
        <translation>סיום המשחק הנוכחי?</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="175"/>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;מופסק&lt;/b&gt;&lt;/big&gt;&lt;br&gt;הקלק לחזרה למשחק.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="403"/>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;המשחק נגמר!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;הקלק להתחלת משחק חדש.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>בחירת שפת יישום:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Gottet Scores</source>
        <translation>תוצאות Gottet</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Level</source>
        <translation>שלב</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Lines</source>
        <translation>שורות</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="56"/>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <location filename="../src/window.cpp" line="222"/>
        <source>Gottet</source>
        <translation>‫Gottet</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="94"/>
        <source>Click to start a new game.</source>
        <translation>הקלק להתחלת משחק חדש.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="114"/>
        <source>&amp;Pause</source>
        <translation>ה&amp;פסקה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="114"/>
        <location filename="../src/window.cpp" line="116"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="116"/>
        <source>&amp;Resume</source>
        <translation>ח&amp;זרה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="119"/>
        <source>&amp;Scores</source>
        <translation>&amp;תוצאות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="124"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="126"/>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="127"/>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="128"/>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;QT</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="142"/>
        <source>Next Piece</source>
        <translation>חתיכה הבאה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="144"/>
        <source>Level</source>
        <translation>שלב</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="146"/>
        <source>Removed Lines</source>
        <translation>שורות שהוסרו</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="148"/>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="221"/>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="223"/>
        <source>A tetris clone I made for my wife</source>
        <translation>חיקוי משחק טטריס שהכנתי עבור אשתי</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="224"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="225"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet-1.0.6-src.tar.bz2: gottet-1.0.6/translations/gottet_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="89"/>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="89"/>
        <source>End the current game?</source>
        <translation>לסיים את המשחק הנוכחי?</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="175"/>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;מושהה&lt;/b&gt;&lt;/big&gt;&lt;br&gt;הקלק לחזרה למשחק.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="403"/>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;המשחק נגמר!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;הקלק להתחלת משחק חדש.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>בחירת שפת יישום:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Gottet Scores</source>
        <translation>תוצאות Gottet</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Level</source>
        <translation>שלב</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Lines</source>
        <translation>שורות</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="56"/>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <location filename="../src/window.cpp" line="221"/>
        <source>Gottet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>Click to start a new game.</source>
        <translation>הקלק להתחלת משחק חדש.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="111"/>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>&amp;Pause</source>
        <translation>ה&amp;שהה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <location filename="../src/window.cpp" line="115"/>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="115"/>
        <source>&amp;Resume</source>
        <translation>ח&amp;זור</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="118"/>
        <source>&amp;Scores</source>
        <translation>&amp;תוצאות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="125"/>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="126"/>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="127"/>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;QT</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="141"/>
        <source>Next Piece</source>
        <translation>חתיכה הבאה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="143"/>
        <source>Level</source>
        <translation>שלב</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="145"/>
        <source>Removed Lines</source>
        <translation>שורות שהוסרו</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="147"/>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="220"/>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>A tetris clone I made for my wife</source>
        <translation>חיקוי משחק טטריס שהכנתי עבור אשתי</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="223"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="224"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
